Index: trunk/src/org/openstreetmap/josm/data/validation/tests/DeprecatedTags.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/validation/tests/DeprecatedTags.java	(revision 6443)
+++ trunk/src/org/openstreetmap/josm/data/validation/tests/DeprecatedTags.java	(revision 6447)
@@ -23,5 +23,5 @@
 
 /**
  * Checks and corrects deprecated tags.
  * @since 4442
  */
@@ -140,4 +140,7 @@
                 test("monitoring:river_level").
                 alternative("monitoring:water_level"));
+        // see #9365 - Useless tag layer=0
+        checks.add(new UnnecessaryTagCheck(2130).
+                testAndRemove("layer", "0"));
     }
 
@@ -172,7 +175,7 @@
 
         private int code;
-        private final List<Tag> test = new LinkedList<Tag>();
-        private final List<Tag> change = new LinkedList<Tag>();
-        private final List<Tag> alternatives = new LinkedList<Tag>();
+        protected final List<Tag> test = new LinkedList<Tag>();
+        protected final List<Tag> change = new LinkedList<Tag>();
+        protected final List<Tag> alternatives = new LinkedList<Tag>();
 
         public DeprecationCheck(int code) {
@@ -242,4 +245,16 @@
         }
     }
+    
+    private static class UnnecessaryTagCheck extends DeprecationCheck {
+
+        public UnnecessaryTagCheck(int code) {
+            super(code);
+        }
+
+        @Override
+        String getDescription() {
+            return tr("{0} is unnecessary", Utils.join(", ", test));
+        }
+    }
 
     private class DeprecationError extends TestError {
@@ -23,5 +23,5 @@
 
 /**
- * Checks and corrects deprecated tags.
+ * Checks and corrects deprecated and unnecessary tags.
  * @since 4442
  */
